@@ -36,6 +36,8 @@ import io.undertow.testutils.DefaultServer;
 import io.undertow.testutils.HttpClientUtils;
 import io.undertow.testutils.TestHttpClient;
 import io.undertow.util.StatusCodes;
+import jakarta.servlet.DispatcherType;
+import jakarta.servlet.ServletException;
 import org.apache.http.HttpResponse;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.methods.HttpPost;
@@ -45,11 +47,7 @@ import org.junit.BeforeClass;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
-import javax.servlet.DispatcherType;
-import javax.servlet.ServletException;
 import java.io.IOException;
-import java.net.URLEncoder;
-import java.nio.charset.StandardCharsets;
 
 import static org.junit.Assert.assertEquals;
 import static org.wildfly.common.Assert.assertTrue;
@@ -210,12 +208,11 @@ public class DispatcherIncludeTestCase {
             assertEquals(StatusCodes.OK, result.getStatusLine().getStatusCode());
             String response = HttpClientUtils.readResponse(result);
             MatcherAssert.assertThat(response, CoreMatchers.containsString(IncludeServlet.MESSAGE + "pathInfo:null queryString:n1=v1&n2=v2 servletPath:/dispatch requestUri:/servletContext/dispatch\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.request_uri:/servletContext/path-include\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.context_path:/servletContext\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.servlet_path:/path-include\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.path_info:null\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.query_string:url=http://test.com\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.mapping:"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.request_uri:/servletContext/path-include\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.context_path:/servletContext\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.servlet_path:/path-include\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.path_info:null\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.query_string:url=http://test.com\r\n"));
         } finally {
             client.getConnectionManager().shutdown();
         }
@@ -231,12 +228,12 @@ public class DispatcherIncludeTestCase {
             assertEquals(StatusCodes.OK, result.getStatusLine().getStatusCode());
             String response = HttpClientUtils.readResponse(result);
             MatcherAssert.assertThat(response, CoreMatchers.containsString(IncludeServlet.MESSAGE + "pathInfo:/dis%patch queryString:n1=v1&n2=v%252 servletPath:/dispatch requestUri:/servletContext/dispatch/dis%25patch\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.request_uri:/servletContext/path-include/path%25include\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.context_path:/servletContext\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.servlet_path:/path-include\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.path_info:/path%include\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.query_string:n2=v%253\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.mapping:"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.request_uri:/servletContext/path-include/path%25include\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.context_path:/servletContext\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.servlet_path:/path-include\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.path_info:/path%include\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.query_string:n2=v%253\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.mapping:"));
         } finally {
             client.getConnectionManager().shutdown();
         }
@@ -252,12 +249,12 @@ public class DispatcherIncludeTestCase {
             assertEquals(StatusCodes.OK, result.getStatusLine().getStatusCode());
             String response = HttpClientUtils.readResponse(result);
             MatcherAssert.assertThat(response, CoreMatchers.containsString(IncludeServlet.MESSAGE + "pathInfo:null queryString:n1=v1&n2=v%252 servletPath:/dis%patch.dispatch requestUri:/servletContext/dis%25patch.dispatch\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.request_uri:/servletContext/path%25include.includeinfo\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.context_path:/servletContext\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.servlet_path:/path%include.includeinfo\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.path_info:null\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.query_string:n2=v%253\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.mapping:"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.request_uri:/servletContext/path%25include.includeinfo\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.context_path:/servletContext\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.servlet_path:/path%include.includeinfo\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.path_info:null\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.query_string:n2=v%253\r\n"));
+            MatcherAssert.assertThat(response, CoreMatchers.containsString("jakarta.servlet.include.mapping:"));
         } finally {
             client.getConnectionManager().shutdown();
         }
@@ -287,38 +284,13 @@ public class DispatcherIncludeTestCase {
             final String response = HttpClientUtils.readResponse(result);
             //UNDERTOW-2245 javax.servlet.forward.mapping request attribute is not available in servlets forwarded with RequestDispatcher
 
-            assertTrue(DispatcherUtil.containsWord(response,"javax.servlet.include.context_path"));
-            assertTrue(DispatcherUtil.containsWord(response,"javax.servlet.include.servlet_path"));
-            assertTrue(DispatcherUtil.containsWord(response,"javax.servlet.include.request_uri"));
-            assertTrue(DispatcherUtil.containsWord(response,"javax.servlet.include.mapping"));
-            assertTrue(DispatcherUtil.containsWord(response,"javax.servlet.include.query_string"));
+            assertTrue(DispatcherUtil.containsWord(response,"jakarta.servlet.include.context_path"));
+            assertTrue(DispatcherUtil.containsWord(response,"jakarta.servlet.include.servlet_path"));
+            assertTrue(DispatcherUtil.containsWord(response,"jakarta.servlet.include.request_uri"));
+            assertTrue(DispatcherUtil.containsWord(response,"jakarta.servlet.include.mapping"));
 
         } finally {
             client.getConnectionManager().shutdown();
         }
     }
-
-    @Test
-    public void testDisptacherServletIncludeNest() throws IOException, InterruptedException {
-        TestHttpClient client = new TestHttpClient();
-        try {
-            HttpGet get = new HttpGet(DefaultServer.getDefaultServerURL() + "/servletContext/dis%25patch.dispatch?n1=v1&n2=v%252");
-            String include = URLEncoder.encode("/path%25include.includeinfo?n4=v4", StandardCharsets.UTF_8.name());
-            get.setHeader("include", "/servletContext/dis%25patch.dispatch?n3=v3&include=" + include);
-            HttpResponse result = client.execute(get);
-            assertEquals(StatusCodes.OK, result.getStatusLine().getStatusCode());
-            String response = HttpClientUtils.readResponse(result);
-            MatcherAssert.assertThat(response, CoreMatchers.containsString(IncludeServlet.MESSAGE + "pathInfo:null queryString:n1=v1&n2=v%252 servletPath:/dis%patch.dispatch requestUri:/servletContext/dis%25patch.dispatch\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.request_uri:/servletContext/path%25include.includeinfo\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.context_path:/servletContext\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.servlet_path:/path%include.includeinfo\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.path_info:null\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.query_string:n4=v4\r\n"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("javax.servlet.include.mapping:"));
-            MatcherAssert.assertThat(response, CoreMatchers.containsString("request params:include=/path%25include.includeinfo?n4=v4n1=v1n2=v%2n3=v3n4=v4\r\n"));
-        } finally {
-            client.getConnectionManager().shutdown();
-        }
-    }
-
 }
