@@ -19,14 +19,11 @@ package io.undertow.servlet.test.dispatcher;
 
 import java.io.IOException;
 import java.io.PrintWriter;
-import java.util.Arrays;
-import java.util.Map;
-import java.util.Optional;
 
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 /**
  * @author rmartinc
@@ -41,19 +38,12 @@ public class IncludePathTestServlet extends HttpServlet {
             out.print(" servletPath:" + req.getServletPath());
             out.println(" requestUri:" + req.getRequestURI());
 
-            out.println("javax.servlet.include.request_uri:" + req.getAttribute("javax.servlet.include.request_uri"));
-            out.println("javax.servlet.include.context_path:" + req.getAttribute("javax.servlet.include.context_path"));
-            out.println("javax.servlet.include.servlet_path:" + req.getAttribute("javax.servlet.include.servlet_path"));
-            out.println("javax.servlet.include.path_info:" + req.getAttribute("javax.servlet.include.path_info"));
-            out.println("javax.servlet.include.query_string:" + req.getAttribute("javax.servlet.include.query_string"));
-            out.println("javax.servlet.include.mapping:" + req.getAttribute("javax.servlet.include.mapping"));
-
-            StringBuilder sb = new StringBuilder();
-            for (Map.Entry<String, String[]> entry: req.getParameterMap().entrySet()) {
-                Optional<String> r = Arrays.stream(entry.getValue()).reduce((i, j) -> i + "," + j);
-                sb.append(entry.getKey()).append("=").append(r.orElse(""));
-            }
-            out.println("request params:" + sb);
+            out.println("jakarta.servlet.include.request_uri:" + req.getAttribute("jakarta.servlet.include.request_uri"));
+            out.println("jakarta.servlet.include.context_path:" + req.getAttribute("jakarta.servlet.include.context_path"));
+            out.println("jakarta.servlet.include.servlet_path:" + req.getAttribute("jakarta.servlet.include.servlet_path"));
+            out.println("jakarta.servlet.include.path_info:" + req.getAttribute("jakarta.servlet.include.path_info"));
+            out.println("jakarta.servlet.include.query_string:" + req.getAttribute("jakarta.servlet.include.query_string"));
+            out.println("jakarta.servlet.include.mapping:" + req.getAttribute("jakarta.servlet.include.mapping"));
         }
     }
 }
